@@ -30,6 +30,8 @@ impl StreamEmitter {
         res_id: Option<u64>,
     ) -> Result<EmitMetadata> {
         let data_bytes = rmp_serde::to_vec(&data)?;
+        log::debug!("Emitting event {:?}:{}", namespace, event);
+
         let event = if let Some(namespace) = namespace {
             Event::with_namespace(namespace.to_string(), event.to_string(), data_bytes, res_id)
         } else {
@@ -38,6 +40,7 @@ impl StreamEmitter {
 
         let event_bytes = event.to_bytes()?;
         {
+            log::trace!("Writing {} bytes", event_bytes.len());
             let mut stream = self.stream.lock().await;
             (*stream).write_all(&event_bytes[..]).await?;
         }
@@ -75,7 +78,7 @@ impl StreamEmitter {
         self._emit(None, event.as_ref(), data, Some(event_id)).await
     }
 
-    /// Emits a response to an event
+    /// Emits a response to an event to a namespace
     pub async fn emit_response_to<S1: AsRef<str>, S2: AsRef<str>, T: Serialize>(
         &self,
         event_id: u64,
